@@ -435,8 +435,7 @@ class NeutronShell(app.App):
         parser.add_argument(
             '--os-auth-strategy', metavar='<auth-strategy>',
             default=env('OS_AUTH_STRATEGY', default='keystone'),
-            help=_('DEPRECATED! Only keystone is supported.'))
-
+            help=_('Valid values are keystone, noauth, and rackspace.'))
         parser.add_argument(
             '--os_auth_strategy',
             help=argparse.SUPPRESS)
@@ -594,7 +593,7 @@ class NeutronShell(app.App):
             help=argparse.SUPPRESS)
 
         parser.add_argument(
-            '--timeout', metavar='<seconds>',
+            '--http-timeout', metavar='<seconds>',
             default=env('OS_NETWORK_TIMEOUT', default=None), type=float,
             help=_('Timeout in seconds to wait for an HTTP response. Defaults '
                    'to env[OS_NETWORK_TIMEOUT] or None if not specified.'))
@@ -774,6 +773,18 @@ class NeutronShell(app.App):
                     raise exc.CommandError(
                         _("You must provide an auth url via"
                           " either --os-auth-url or via env[OS_AUTH_URL]"))
+        elif self.options.os_auth_strategy == 'rackspace':
+            if not self.options.os_token:
+                raise exc.CommandError(
+                    _("You must provide your API Key via"
+                      " either --os-token or env[OS_TOKEN]"))
+
+            if (not self.options.os_username
+                and not self.options.os_user_id):
+                raise exc.CommandError(
+                    _("You must provide a username or user ID via"
+                      "  --os-username, env[OS_USERNAME] or"
+                      "  --os-user_id, env[OS_USER_ID]"))
         else:   # not keystone
             if not self.options.os_url:
                 raise exc.CommandError(
@@ -801,11 +812,12 @@ class NeutronShell(app.App):
             endpoint_type=self.options.os_endpoint_type or self.endpoint_type,
             insecure=self.options.insecure,
             ca_cert=self.options.os_cacert,
-            timeout=self.options.timeout,
+            timeout=self.options.http_timeout,
             retries=self.options.retries,
             raise_errors=False,
-            session=(None if self.options.os_auth_strategy == 'rackspace' else
-                     auth_session),
+            # FIXME (roaet) we need to set the session to what it used to be
+            # after the identity issue has been fixed
+            session=None,
             auth=auth_session.auth,
             log_credentials=True)
         return
